@@ -1,16 +1,16 @@
-Index: geos/source/headers/geos/planargraph/DirectedEdgeStar.h
+Index: geos/include/geos/planargraph/DirectedEdgeStar.h
 ===================================================================
---- geos.orig/source/headers/geos/planargraph/DirectedEdgeStar.h	2011-05-25 15:32:28.000000000 +0200
-+++ geos/source/headers/geos/planargraph/DirectedEdgeStar.h	2011-05-25 15:33:06.000000000 +0200
-@@ -20,6 +20,7 @@
+--- geos.orig/include/geos/planargraph/DirectedEdgeStar.h	2013-12-06 13:44:31.720065393 +0100
++++ geos/include/geos/planargraph/DirectedEdgeStar.h	2013-12-06 13:44:31.716065384 +0100
+@@ -19,6 +19,7 @@
  #include <geos/export.h>
  
  #include <vector>
 +#include <cstddef>
  
- // Forward declarations
- namespace geos {
-@@ -35,6 +36,8 @@
+ #ifdef _MSC_VER
+ #pragma warning(push)
+@@ -39,6 +40,8 @@
  namespace geos {
  namespace planargraph { // geos.planargraph
  
